#!/bin/sh

CID=$1

export LANG=C

##############################################################################
# Directories on the local disk
##############################################################################

HOMDIR=/home/lcas
SFTDIR=${HOMDIR}/soft
LOGDIR=${HOMDIR}/logs
ORGDIR=${HOMDIR}/data/incoming
STFILE=${HOMDIR}/logs/move_image-1.log
NEWDIR=${HOMDIR}/data/jpgs_${CID}
MOVDIR=${HOMDIR}/data/movs_${CID}
KEODIR=${HOMDIR}/data/keos_${CID}
TMPDIR=${HOMDIR}/data/tmps_${CID}
AVEDIR=${HOMDIR}/data/tmp_aves_${CID}
DRBDIR=${HOMDIR}/Dropbox/${CID}


##############################################################################
# Commands
##############################################################################

MKDIR=/bin/mkdir
MV=/bin/mv
RM=/bin/rm
CP=/bin/cp
TAR=/bin/tar


##############################################################################
# Identify the day of today, yesterday and 30 days ago
##############################################################################

# Today
YY0=$(/bin/date +%y)
MM0=$(/bin/date +%m)
DD0=$(/bin/date +%d)
DA0=20$YY0$MM0$DD0

# Yesterday
YY1=$(/bin/date --date '1 day ago' +%y)
MM1=$(/bin/date --date '1 day ago' +%m)
DD1=$(/bin/date --date '1 day ago' +%d)
DA1=20$YY1$MM1$DD1

# 30 days ago
YY5=$(/bin/date --date '30 day ago' +%y)
MM5=$(/bin/date --date '30 day ago' +%m)
DD5=$(/bin/date --date '30 day ago' +%d)
DA5=20$YY5$MM5$DD5


##############################################################################
# Replace the JPG files from incoming directory to the jpgs directory
##############################################################################

NOWTIME=`/bin/date`
echo $NOWTIME': START Replacing JPG images of '${CID}' on '${DA0} >> $STFILE
FILENUM=`ls -1 ${ORGDIR}/${CID}_${DA1}*.jpg ${ORBDIR}/${CID}_${DA0}*.jpg 2> /dev/null | wc -l`
if [ ${FILENUM} -eq 0 ]
then NOWTIME=`/bin/date`
     echo $NOWTIME': No JPG (8-bit) images on '${DA0}': QUIT' >> $STFILE
     echo ' ' >> $STFILE
else
mkdir -p ${NEWDIR}/${DA0}
mv ${ORGDIR}/${CID}_${DA1}*.jpg ${NEWDIR}/${DA0}/
mv ${ORGDIR}/${CID}_${DA0}*.jpg ${NEWDIR}/${DA0}/
echo $NOWTIME': COMPLETE!' >> $STFILE


##############################################################################
# Make a movie
##############################################################################
NOWTIME=`/bin/date`
echo $NOWTIME': START Making AVI movie on '${DA0} >> $STFILE
mkdir -p ${MOVDIR}
mkdir -p ${TMPDIR}
mkdir -p ${AVEDIR}
rm -f ${TMPDIR}/*
rm -f ${AVEDIR}/*

TN=1
HH=0
while [ $HH -le 23 ]
do MM=0
   while [ $MM -le 59 ]
   do NHH=`printf "%02d" $HH`
      NMM=`printf "%02d" $MM`
      FNUM=`ls -1 ${NEWDIR}/${DA0}/${CID}_${DA1}${NHH}${NMM}*.jpg 2> /dev/null | wc -l`
      if [ ${FNUM} -ne 0 ]
      then convert ${NEWDIR}/${DA0}/${CID}_${DA1}${NHH}${NMM}*.jpg -evaluate-sequence mean ${TMPDIR}/${TN}.jpg
	   convert ${NEWDIR}/${DA0}/${CID}_${DA1}${NHH}${NMM}*.jpg -evaluate-sequence mean ${AVEDIR}/${CID}_${DA1}${NHH}${NMM}.jpg
	   TN=`expr $TN + 1`
      fi
      MM=`expr $MM + 1`
   done
   HH=`expr $HH + 1`
done

HH=0
while [ $HH -le 23 ]
do MM=0
   while [ $MM -le 59 ]
   do NHH=`printf "%02d" $HH`
      NMM=`printf "%02d" $MM`
      FNUM=`ls -1 ${NEWDIR}/${DA0}/${CID}_${DA0}${NHH}${NMM}*.jpg 2> /dev/null | wc -l`
      if [ ${FNUM} -ne 0 ]
      then convert ${NEWDIR}/${DA0}/${CID}_${DA0}${NHH}${NMM}*.jpg -evaluate-sequence mean ${TMPDIR}/${TN}.jpg
	   convert ${NEWDIR}/${DA0}/${CID}_${DA0}${NHH}${NMM}*.jpg -evaluate-sequence mean ${AVEDIR}/${CID}_${DA0}${NHH}${NMM}.jpg
	   TN=`expr $TN + 1`
      fi
      MM=`expr $MM + 1`
   done
   HH=`expr $HH + 1`
done

ffmpeg -r 30 -i ${TMPDIR}/%d.jpg -qscale 0.1 ${MOVDIR}/${CID}_${DA0}.mov
mkdir -p ${DRBDIR}/movs/
cp ${MOVDIR}/${CID}_${DA0}.mov ${DRBDIR}/movs/
cp ${MOVDIR}/${CID}_${DA0}.mov ${DRBDIR}/movs/latest_mov.mov
rm -rf ${TMPDIR}
echo $NOWTIME': COMPLETE!' >> $STFILE


##############################################################################
# Make a tar ball and copy it to the backup disk
##############################################################################
NOWTIME=`/bin/date`
echo $NOWTIME': START Making TAR ball on '${DA0} >> $STFILE
cd ${AVEDIR}
$TAR zcfv ${NEWDIR}/${DA0}.tgz ${CID}_*
mkdir -p ${DRBDIR}/jpgs
cp ${NEWDIR}/${DA0}.tgz ${DRBDIR}/jpgs/
rm -rf ${NEWDIR}/${DA0}
rm -rf ${AVEDIR}
cd ${HOMDIR}
NOWTIME=`/bin/date`
echo $NOWTIME': COMPLETE!' >> $STFILE

fi


##############################################################################
# Delete old data (older than 30 days) from the local data directory
##############################################################################
rm -rf ${NEWDIR}/${DA5}.tgz
rm -rf ${MOVDIR}/${CID}_${DA5}.mov
rm -rf ${LOGDIR}/${DA5}-1.log

##############################################################################
# Copy the log file to the local Dropbox directory
##############################################################################
mkdir -p ${DRBDIR}/logs/
cp ${STFILE} ${DRBDIR}/logs/
cp ${LOGDIR}/${DA1}-1.log ${DRBDIR}/logs/

